# Kubo changelog v0.23

- [v0.23.0](#v0230)

## v0.23.0

- [Overview](#overview)
- [🔦 Highlights](#-highlights)
  - [Mplex deprecation](#mplex-deprecation)
  - [Gateway: meaningful CAR responses on Not Found errors](#gateway-meaningful-car-responses-on-not-found-errors)
  - [Gateway: added `Gateway.DisableHTMLErrors` configuration option](#gateway-added-gatewaydisablehtmlerrors-configuration-option)
  - [Binary characters in file names: no longer works with old clients and new Kubo servers](#binary-characters-in-file-names-no-longer-works-with-old-clients-and-new-kubo-servers)
  - [Self-hosting `/routing/v1` endpoint for delegated routing needs](#self-hosting-routingv1-endpoint-for-delegated-routing-needs)
  - [Trustless Gateway Over Libp2p Experiment](#trustless-gateway-over-libp2p-experiment)
  - [Removal of `/quic` (Draft 29) support](#removal-of-quic-draft-29-support)
  - [Better Caching of multiaddresses for providers in DHT servers](#better-caching-of-multiaddresses-for-providers-in-dht-servers)
  - [fixed FUSE multiblock structures](#fixed-fuse-multiblock-structures)
- [📝 Changelog](#-changelog)
- [👨‍👩‍👧‍👦 Contributors](#-contributors)

### Overview

### 🔦 Highlights

#### Mplex deprecation

Mplex is being deprecated, this is because it is unreliable and
randomly drop streams when sending data *too fast*.

New pieces of code rely on backpressure, that means the stream will dynamicaly
slow down the sending rate if data is getting backed up.
Backpressure is provided by **Yamux** and **QUIC**.

In case you need compatibility with older implementations that do not ship with
Yamux (like default's JS-IPFS) you can turned it back ON in the config with:
```console
$ ipfs config --json Swarm.Transports.Multiplexers.Mplex 200
```

We will completely remove Mplex in v0.24 as it makes protocols very bad to implement,
if you are in this situation you need to add yamux support to your other implementation.

#### Gateway: meaningful CAR responses on Not Found errors

When requesting a CAR from the gateway, the root of the CAR might no longer be
meaningful. By default, the CAR root will be the last resolvable segment of the
path. However, in situations where the path cannot be resolved, such as when
the path does not exist, a CAR will be sent with a root of `bafkqaaa` (empty CID).

This CAR will contain all blocks necessary to validate that the path does not
exist without having to trust the gateway.

#### Gateway: added `Gateway.DisableHTMLErrors` configuration option

The `Gateway.DisableHTMLErrors` configuration option forces errors to be
displayed in browsers as plain text (`text/plain`) rather than HTML error
pages. It's especially beneficial for whitelabel or middleware deployments that
wish to avoid IPFS branding and links on error pages in browsers.

#### Binary characters in file names: no longer works with old clients and new Kubo servers

In this version, we updated Kubo to support Go 1.20+. In Go 1.20, a regression
regarding multipart headers was [introduced](https://github.com/golang/go/issues/60674).
This only affects `ipfs add` when a file name has binary characters in its name.
As a consequence, we had to update the encoding of the file name headers. This is
the compatibility table:

|            | New Client | Old Client  |
|------------|------------|-------------|
| New Server | ✅         | 🟡*         |
| Old Server | ✅         | ✅          |

*Old clients can only send Unicode file paths to the server.

#### Self-hosting `/routing/v1` endpoint for delegated routing needs

The `Routing` system configured in Kubo can be now exposed on the gateway port as a standard
HTTP [Routing V1](https://specs.ipfs.tech/routing/http-routing-v1/) API endpoint. This allows 
self-hosting and experimentation with custom delegated routers. This is disabled by default,
but can be enabled by setting [`Gateway.ExposeRoutingAPI`](https://github.com/ipfs/kubo/blob/master/docs/config.md#gatewayexposeroutingapi) to `true` .

#### Trustless Gateway Over Libp2p Experiment

In this update, we've introduced an experimental opt-in feature allowing users to
serve a subset of [Trustless Gateway](https://specs.ipfs.tech/http-gateways/trustless-gateway/) responses,
such as blocks and CARs, over libp2p. This enhancement leverages the ongoing
[`/http/1.1` specification work in libp2p](https://github.com/libp2p/specs/pull/508)
to make it easier to support HTTP semantics over libp2p streams.

This development means that if users wish to utilize the Trustless Gateway API
for data transport, they can now do so even in scenarios where standard HTTP
might be problematic, such as when the endpoint is behind a firewall or when
attempting to serve data to a browser without a CA certificate.

See [HTTP Gateway over Libp2p](https://github.com/ipfs/kubo/blob/master/docs/experimental-features.md#http-gateway-over-libp2p) for details about this experiment.

#### Removal of `/quic` (Draft 29) support

Kubo no longer supports QUIC Draft 29. This means that older nodes aren't able to connect
to newer nodes using QUIC Draft 29. However, they are still able to connect through any other
transport that both nodes talk (such as QUIC RFC 9000, or TCP). QUIC Draft 29 was a preliminary implementation of QUIC before
the official RFC 9000 was published, and it has now been dropped by [`go-libp2p`](https://github.com/libp2p/go-libp2p/releases/tag/v0.30.0)
and therefore Kubo.

In [Kubo 0.18](https://github.com/ipfs/kubo/releases/tag/v0.18.0), we shipped a migration
to have listeners for both `/quic` (Draft 29) and `/quic-v1` (RFC 9000). Similarly, in this
version we are shipping a migration to remove the current `/quic` addresses, maintaining
the `/quic-v1` addresses only. For more background information, check [issue #9496](https://github.com/ipfs/kubo/issues/9496).

#### Better Caching of multiaddresses for providers in DHT servers

Thanks to [probelab.io's RFM17.1](https://github.com/plprobelab/network-measurements/blob/master/results/rfm17.1-sharing-prs-with-multiaddresses.md) DHT servers will [now cache the addresses of content hosts for the lifetime of the provider record](https://github.com/libp2p/go-libp2p-kad-dht/commit/777160f164b8c187c534debd293157031e9f3a02).

This means clients who resolve content from theses servers get a responses which include both peer id and multiaddresses.
In most cases this enables skipping a second query which resolves the peer id to multiaddresses for stable enough peers.

This will improve content fetching lantency in the network overtime as servers updates.

#### fixed FUSE multiblock structures

`ls`ing directories and reading dag-pb files on a fuse volume have been fixed. [#9044](https://github.com/ipfs/kubo/issues/9044)
Thx a lot @bmwiedemann for debugging this issue.

### 📝 Changelog

### 👨‍👩‍👧‍👦 Contributors
